@@ -1,6 +1,6 @@
 /* 
  * This file is part of SharedArray.
- * Copyright (C) 2014-2016 Mathieu Mirmont <mat@parad0x.org>
+ * Copyright (C) 2014-2017 Mathieu Mirmont <mat@parad0x.org>
  * 
  * SharedArray is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,11 +43,17 @@ struct array_meta {
 extern PyStructSequence_Desc PyArrayDescObject_Desc;
 extern PyTypeObject PyArrayDescObject_Type;
 
-/* Module functions */
+/* Main functions */
 extern PyObject *shared_array_create(PyObject *self, PyObject *args, PyObject *kwds);
 extern PyObject *shared_array_attach(PyObject *self, PyObject *args);
 extern PyObject *shared_array_delete(PyObject *self, PyObject *args);
+
+/* SHM list function */
+#ifdef __linux__
 extern PyObject *shared_array_list(PyObject *self, PyObject *args);
+#endif
+
+/* Memory locking functions */
 extern PyObject *shared_array_msync(PyObject *self, PyObject *args, PyObject *kwds);
 extern PyObject *shared_array_mlock(PyObject *self, PyObject *args, PyObject *kwds);
 extern PyObject *shared_array_munlock(PyObject *self, PyObject *args, PyObject *kwds);
